@@ -1,3 +1,4 @@
+/* $Id: misc.c,v 1.1 2004/08/28 19:25:46 dannybackx Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -33,7 +34,7 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#include "mwm.h"
+#include <LTconfig.h>
 
 #include <stdio.h>
 #ifdef HAVE_SYS_TYPES_H
@@ -41,24 +42,23 @@
 #endif
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#ifdef TIME_WITH_SYS_TIME
-#include <time.h>
-#endif
 #endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
 
+#include <X11/Intrinsic.h>
 #include <X11/keysym.h>
 
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
 #include <Xm/XmosP.h>
 #if XmVERSION >= 2
 #include <XmI/XmI.h>
 #endif
 
+#include "mwm.h"
+
 
 static Time lastTimestamp = CurrentTime;
 
