@@ -1,4 +1,4 @@
-/* $Id: mwm.h,v 1.27 2001/10/29 08:59:26 amai Exp $ */
+/* $Id: mwm.h,v 1.1 2004/08/28 19:25:46 dannybackx Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -32,12 +32,17 @@
 /***********************************************************************
  * The rest of it is all my fault -- MLM
  * mwm - "LessTif Window Manager"
+ *
+ * Copyright (C) 1995-2002 LessTif Development Team
+ *
  ***********************************************************************/
 
 
 #ifndef _MWM_H
 #define _MWM_H
 
+#include <limits.h>
+
 #include <Xm/Xm.h>
 #include <Xm/MwmUtil.h>
 
@@ -56,14 +61,27 @@
 #define MWM_VERSION		"Lesstif mwm Release"
 #define OPT_MULTISCREEN		"-multiscreen"
 #define OPT_SCREENS		"-screens"
-#ifndef __EMX__
+
+
+#ifndef MWM_DDIR
+#define MWM_DDIR "/usr/lib/X11/mwm"
+#endif
+
+#ifndef XINCL_PATH
+#define XINCL_PATH "/usr/X11/include"
+#endif
+
+
+#ifdef __EMX__
+#define MWM_ICONDIR	"/XFree86/include/X11/bitmaps;/XFree86/include/X11/pixmaps"
+/* amai: this is an ugly hack ... */
+#ifdef MWM_DDIR
+#undef MWM_DDIR
+#endif
+#define MWM_DDIR (char*)__XOS2RedirRoot("/XFree86/lib/X11/mwm")
+#else /* !__EMX__ */
 #define MWM_ICONDIR		XINCL_PATH"/X11/bitmaps:"XINCL_PATH"/X11/pixmaps"
-#else
-#define MWM_ICONDIR		"/XFree86/include/X11/bitmaps;/XFree86/include/X11/pixmaps"
-/* char mwm_icondir[255]; */
 #endif
-#define USAGE \
-"Mwm Ver %s\n\nusage: mwm [-display dpy] [-debug] [-xrm resourcestring] [-multiscreen] [-name name] [-screens name [name [...]]]\n"
 
 
 /*
@@ -1065,12 +1083,12 @@ extern void	_WmATopShadowPixmapDefault(Widget w, int offset,
 extern char	mwm_getc(void);
 extern void	mwm_putc(char c);
 extern void	mwm_unputc(char c);
-extern void	yyerror(char *fmt, ...);
+extern void	yyerror(const char *fmt, ...);
 
 /* Misc utility functions */
 extern int SetEnvironment(const char *key, const char *value);
 void ReapChildren(void);
-
+extern char *find_config_file(void);
 
 /*
  * global data
@@ -1099,7 +1117,6 @@ extern Bool NeedToResizeToo;
 extern volatile int alarmed;
 extern Bool debugging;
 extern char **g_argv;
-extern int verbose;
 
 /* pager.c: */
 extern Bool DoHandlePageing;
@@ -1124,4 +1141,13 @@ extern Atom     XA_MWM_MESSAGES;
 extern Atom     XA_MWM_MENU;
 extern Atom     XA_MWM_INFO;
 
+
+/* some utility #defines */
+#ifdef PATH_MAX
+# define MAX_PATH_LEN PATH_MAX
+#else
+# define MAX_PATH_LEN	2048 /* this is OS dependent, but this should catch most */
+#endif
+
+
 #endif /* _MWM_H */
