@@ -1,8 +1,9 @@
 /**
  *
- * $Id: resources.c,v 1.15 2001/10/24 12:06:44 amai Exp $
+ * $Id: resources.c,v 1.1 2004/08/28 19:25:46 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -25,11 +26,10 @@
 #include <LTconfig.h>
 
 #include <stdio.h>
-
-#include <Xm/Xm.h>
-#include <Xm/MwmUtil.h>
+#include <string.h>
 
 #include <Xm/XmP.h>
+#include <Xm/MwmUtil.h>
 #include <Xm/XmStrDefs.h>
 
 #include "mwm.h"
@@ -451,7 +451,7 @@ static XtResource mwm_screen_resources[] =
 	XmRImmediate, (XtPointer)False
     },
     {
-	XmNfeedbackGeometry, XmCFeedbackGeometry, XmRString,
+	XmNfeedbackGeometry, XmCFeedbackGeometry, XmRGeometry,
 	sizeof(Geometry), Offset(feedback_geometry),
 	XmRCallProc, (XtPointer)NULL
     },
@@ -461,8 +461,8 @@ static XtResource mwm_screen_resources[] =
 	XmRCallProc, (XtPointer)_WmDefaultBorderWidth
     },
     {
-	XmNiconBoxGeometry, XmCIconBoxGeometry, XmRString,
-	sizeof(String), Offset(icon_box_geometry),
+	XmNiconBoxGeometry, XmCIconBoxGeometry, XmRGeometry,
+	sizeof(Geometry), Offset(icon_box_geometry),
 	XmRCallProc, (XtPointer)NULL
     },
     {
