@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ExpressionList.c,v 1.4 1999/05/28 20:43:07 danny Exp $
+ * $Id: ExpressionList.c,v 1.1 2004/08/28 19:25:46 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -28,12 +29,12 @@
 
 #include <LTconfig.h>
 
+#include <string.h>
+
 #include "ExpressionList.h"
 
-extern FILE *outFile;
+#include "main.h"
 
-extern ExpressionList GlobalSymbolTable;
-extern ExpressionList LocalSymbolTable;
 
 #if 0
 ExpressionElement *
@@ -230,7 +231,7 @@ ExpressionListEmit(ExpressionList *this)
 
 	if (NULL == i->expr)
 	{
-	    Exit(LOC,
+	    __MrmExit(LOC,
 	      "The code to create %s has not been implemented correctly yet\n",
 		 i->name);
 	}
@@ -274,7 +275,7 @@ ExpressionListLookup(ExpressionType **this)
 
     if (NULL == t)
     {
-	Exit(LOC, "Can't find in symbol tables\n");
+	__MrmExit(LOC, "Can't find in symbol tables\n");
     }
 
     (*this) = t->expr;
