@@ -1,8 +1,9 @@
 /**
  *
- * $Id: MrmPrivate.h,v 1.1 1997/02/20 22:28:20 miers Exp $
+ * $Id: MrmPrivate.h,v 1.1 2004/08/28 19:23:24 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,8 +24,8 @@
  **/
 
 
-#ifndef MRM_PRIVATE_H
-#define MRM_PRIVATE_H
+#ifndef _MRM_MRMPRIVATE_H
+#define _MRM_MRMPRIVATE_H
 
 #include <Mrm/MrmPublic.h>
 
@@ -37,13 +38,9 @@ typedef struct {
     MrmHierarchy hierarchy_for_display;
 } MrmPerDisplay, *MrmPerDisplayList;
 
-struct MrmHierachyStruct {
-    MrmCount number_of_files;
-    String *files;
-};
 
 #ifdef __cplusplus
 };
 #endif
 
-#endif /* MRM_PRIVATE_H */
+#endif /* _MRM_MRMPRIVATE_H */
