@@ -1,8 +1,9 @@
 /**
  * 
- * $Id: Primitive.h,v 1.1 1997/07/08 17:04:13 miers Exp $
+ * $Id: Primitive.h,v 1.1 2004/08/28 19:23:25 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,8 +23,8 @@
  *
  **/
 
-#ifndef XM_PRIMITIVE_H
-#define XM_PRIMITIVE_H
+#ifndef _XM_PRIMITIVE_H
+#define _XM_PRIMITIVE_H
 
 #include <Xm/Xm.h>
 
@@ -31,7 +32,7 @@
 extern "C" {
 #endif
 
-extern WidgetClass xmPrimitiveWidgetClass;
+XMLIBEXPORT extern WidgetClass xmPrimitiveWidgetClass;
 
 typedef struct _XmPrimitiveRec *XmPrimitiveWidget;
 typedef struct _XmPrimitiveClassRec *XmPrimitiveWidgetClass;
@@ -44,5 +45,4 @@ typedef struct _XmPrimitiveClassRec *XmPrimitiveWidgetClass;
 }
 #endif
 
-#endif
-
+#endif /* _XM_PRIMITIVE_H */
