@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Shadow.c,v 1.2 2005/03/24 19:54:23 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Shadow.c,v 1.3 2005/04/04 07:22:48 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004, 2005 LessTif Development Team 
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Shadow.c,v 1.2 2005/03/24 19:54:23 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Shadow.c,v 1.3 2005/04/04 07:22:48 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -904,8 +904,8 @@ _XmDrawSimpleHighlight(Display *display,
     XRectangle rects[4];
 
     DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(display, d),
-			    "_XmDrawSimpleHighlight(x %d y %d width %d height %d hlt %d)\n",
-			    x, y, width, height, highlight_thick));
+			    "_XmDrawSimpleHighlight(gc %p x %d y %d width %d height %d hlt %d)\n",
+			    gc, x, y, width, height, highlight_thick));
 
     if (highlight_thick >= (width + 1) >> 1 ||
 	highlight_thick >= (height + 1) >> 1)
