@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.19 2001/09/11 17:34:00 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Trait.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2001 LessTif Development Team
+ * Copyright (C) 1997-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.19 2001/09/11 17:34:00 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Trait.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $";
 
 /*
  * This file contains a poor man's implementation of traits.
@@ -48,6 +48,8 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.
 
 #include <LTconfig.h>
 
+#include <stdio.h>    /* for _LtDebugTraitReport() only */
+
 #include <X11/IntrinsicP.h>
 #include <X11/CoreP.h>
 
@@ -71,8 +73,13 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.
 #include <Xm/TransferT.h>
 
 #include <XmI/XmI.h>
+
 #include <XmI/DebugUtil.h>
 
+/* avoid a compiler warning. This interface is just a debugging feature
+   and may disappear in future releases */
+extern void _LtDebugTraitReport(void);
+
 
 /* The numbers below are really just increments */
 #define	NUM_WIDGET_CLASSES	32
@@ -349,11 +356,10 @@ _XmInitTraits(void)
 	XmQTtransfer = XrmStringToQuark("XmQTtransfer");
 }
 
-#if 1
-#include <stdio.h>
-#include <X11/CoreP.h>
 
-void _LtDebugTraitReport(void)
+/* for debugging purposes only - as the name indicates */
+extern void
+_LtDebugTraitReport(void)
 {
 	int		i, j;
 	XrmQuark	q;
@@ -366,4 +372,3 @@ void _LtDebugTraitReport(void)
 		}
 	}
 }
-#endif
