@@ -1,13 +1,15 @@
-/* $Id: test14.c,v 1.2 2000/10/24 14:44:00 amai Exp $ */
+/* $Id: test14.c,v 1.3 2002/05/01 15:47:31 amai Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 
 #include <Xm/BulletinBP.h>
 #include <Xm/DrawnBP.h>
 #include <Xm/DrawP.h>
 
+#include "../../common/Test.h"
+
+
 #ifndef Prim_BottomShadowGC
 #define Prim_BottomShadowGC(w) \
     (((XmPrimitiveWidget)(w))->primitive.bottom_shadow_GC)
