@@ -1,3 +1,5 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/drag_pixmaps/export_bitmap.c,v 1.2 2001/05/23 13:55:31 amai Exp $ */
+
 #include <Xm/Xm.h>
 #include "bitmap.h"
 
@@ -16,7 +18,7 @@ export_bitmap(w, selection, target, type_return, value, length,
 
 	if ((*target != XA_STRING) && (*target != XA_PIXMAP))
 		return False;
-	XtVaGetValues(w, XmNclientData, &bitmap, 0);
+	XtVaGetValues(w, XmNclientData, &bitmap, NULL);
 
 	/* Handle both pixmap and string targets */
 
