@@ -1,4 +1,8 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/form/test27.c,v 1.6 2001/05/16 09:23:15 amai Exp $ */
+
+#include <stdlib.h>
 #include <stdio.h>
+
 #include <Xm/Xm.h>
 #include <Xm/PushB.h>
 #include <Xm/Form.h>
@@ -7,6 +11,8 @@
 #include <Xm/TextF.h>
 #include <Xm/SeparatoG.h>
 
+#include "../../common/Test.h"
+
 
 static char *FallBack[] = {
 		"*.borderWidth: 1",
