@@ -3,6 +3,11 @@
 #include <Xm/Xm.h>
 #include <Xm/PushB.h>
 
+static char *FallBack[] = {
+		"*.geometrySlop: 1",
+		NULL
+};
+
 int
 main(int argc, char **argv)
 {
@@ -13,7 +18,7 @@ main(int argc, char **argv)
 
   XtSetLanguageProc(NULL, NULL, NULL);
 
-  toplevel = XtVaAppInitialize(&app, "Label", NULL, 0, &argc, argv, NULL, NULL);
+  toplevel = XtVaAppInitialize(&app, "Label", NULL, 0, &argc, argv, FallBack, NULL);
 
   fontlist = XmFontListAppendEntry(NULL,
 			   XmFontListEntryCreate("MY_FONT",
@@ -39,7 +44,7 @@ main(int argc, char **argv)
  */
 {
 static XtWidgetGeometry Expected[] = {
-   CWWidth | CWHeight            ,    0,    0,   96,  130, 0,0,0, /* One */
+   CWWidth | CWHeight            ,  267,  282,  100,  130, 0,0,0, /* One */
 };
 /* toplevel should be replaced with to correct applicationShell */
 PrintDetails(toplevel, Expected);
