@@ -33,7 +33,14 @@ main(int argc, char **argv)
 
   XtRealizeWidget(toplevel);
 
-  XtAppMainLoop(app);
+  
+{
+    static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,    3,    3,  300,  300, 0,0,0, /* One */ 
+    };
+    PrintDetails(  toplevel ,Expected);
+};
+   LessTifTestMainLoop(  toplevel );
 
   exit(0);
 }
