@@ -207,7 +207,7 @@ _XmRCSetKidGeo(XmRCKidGeometry kg, Widget instigator)
     }
 }
  
-void
+int
 main(int argc, char **argv)
 {
 	XtAppContext app;
@@ -332,4 +332,6 @@ static XtWidgetGeometry Expected[] = {
 PrintDetails(toplevel, Expected);
 }
 LessTifTestMainLoop(toplevel);
+
+	exit(0);
 }
