@@ -41,7 +41,16 @@ main(int argc, char **argv)
   XtVaGetValues(one, XmNmaximum, &maximum, NULL);
 
   printf ("one.maximum = %u\n", maximum);
-  XtAppMainLoop(app);
+
+  
+{
+    static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,   50,   50,   39,  100, 0,0,0, /* sb */
+   CWWidth | CWHeight | CWX | CWY,   20,    0,   19,  100, 0,0,0, /* Scrollbar */ 
+    };
+    PrintDetails(toplevel,Expected);
+};
+  LessTifTestMainLoop(toplevel);
 
   exit(0);
 }
