@@ -1,9 +1,9 @@
 /**
  *
- * $Id: DumpLayout.c,v 1.20 2001/05/15 08:12:53 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/test/common/DumpLayout.c,v 1.24 2002/05/01 16:01:26 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996-2000 LessTif Development Team
+ * Copyright (C) 1996-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -32,6 +32,8 @@
    Is there a event, or callback one can use to figure out when the
    window has been placed????
  */
+ 
+#include "LTTconfig.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -41,8 +43,8 @@
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
 
-#include "DumpLayout.h"
-
+#define LIB_LTTEST
+#include "Test.h"
 
 typedef struct
 {
@@ -53,9 +55,7 @@ typedef struct
 
 static Boolean GlobalResult = True;
 static int slop;
-extern int GlobalErrors;
 
-int  LessTifTestGetSlop(Widget w);
 
 static void
 PrintWidgetDetails(Widget W, XtWidgetGeometry *ExpectedResults)
